@@ -25,7 +25,7 @@
 #include <tqtimer.h>
 #include <tqguardedptr.h>
 #include <stdlib.h>
-#include <qca.h>
+#include <tqca.h>
 #include "xmpp_xmlcommon.h"
 #include "../xmpp-core/hash.h"
 #include "socks.h"
