@@ -47,7 +47,7 @@
 #include <tqtextstream.h>
 #include <tqguardedptr.h>
 #include <tqtimer.h>
-#include <qca.h>
+#include <tqca.h>
 #include <stdlib.h>
 #include "bytestream.h"
 #include "base64.h"
