@@ -7,7 +7,7 @@
  ***************************************************************************/
 
 /***************************************************************************
- * Contains portions & concept from rfb's x0rfbserver.cc
+ * Contains portions & concept from rfb's x0rfbserver.cpp
  * Copyright (C) 2000 heXoNet Support GmbH, D-66424 Homburg.
  ***************************************************************************/
 
@@ -32,10 +32,11 @@
 #include <tqmutex.h>
 
 #define HAVE_PTHREADS
-#include "rfb.h"
+#include "rfb/rfb.h"
 
 #include <X11/Xlib.h>
 
+#define USE_MODIFIED_BUILTIN_LIBVNCSERVER
 
 
 class TQCloseEvent;
@@ -143,7 +144,9 @@ public:
 	enum rfbNewClientAction handleNewClient(rfbClientPtr cl);
 	void clipboardToServer(const TQString &text);
 	void handleClientGone();
+#ifdef USE_MODIFIED_BUILTIN_LIBVNCSERVER
 	void handleNegotiationFinished(rfbClientPtr cl);
+#endif // USE_MODIFIED_BUILTIN_LIBVNCSERVER
 	int getPort();
 	void startServer(int inetdFd = -1, bool xtestGrab = true);
 
